'use client'
import { useState } from "react";
import toast from 'react-hot-toast';
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import useReSendStore from "@/feature/messenger/store/useReSendStore";
import TypeMessageRe from "@/feature/messenger/components/modals/TypeMessageRe";
import { resendMessageService } from "@/feature/messenger/services/chat/OptionsMessageService";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import { Button, Input, Modal, ModalBody, ModalContent, ModalFooter, ModalHeader, Select, SelectItem } from "@nextui-org/react";

const ReSendMessage = () => {

    //state 
    const [loading, setLoading] = useState(false);
    //store
    const listConversations = useConversationsStore(state => state.defaultListConversation);
    const openModalReSend = useReSendStore(state => state.openModalReSend);
    const message = useReSendStore(state => state.message);
    const hadleCloseModalReSend = useReSendStore(state => state.hadleCloseModalReSend);
    const setCommentary = useReSendStore(state => state.setCommentary);
    const setToSesion = useReSendStore(state => state.setToSesion);
    const commentary = useReSendStore(state => state.commentary);
    const toSesion = useReSendStore(state => state.toSesion);
    const id_chatbot = useConfigChatStore(state => state.idChatbot);

    const handleRadioChange = (event: any) => {
        setToSesion(event.target.value);
    }

    const handleSubmit = async () => {
        if (toSesion.trim() == '') {
            toast.error("Debe seleccionar una conversación");
            return
        }
        if (commentary.trim() == '') {
            toast.error("Debe agregar un comentario");
            return
        }
        setLoading(true)
        const res = await resendMessageService(id_chatbot, toSesion, message.id_log, commentary);
        if (res.success == true) {
            toast.success("Se ha reenviado el mensaje correctamente");
        } else {
            toast.error("Ocurrio un error al reenviar el mensaje");
        }
        setLoading(false)
        hadleCloseModalReSend();
    }

    return (
        <>
            <Modal isOpen={openModalReSend} onOpenChange={() => hadleCloseModalReSend()} size="xl" >
                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalHeader>Reenviar mensaje</ModalHeader>
                            <ModalBody>
                                <div className="p-2">
                                    <Select
                                        label="Conversaciones"
                                        name="select"
                                        placeholder="Seleccione una conversación"
                                        onChange={(e) => handleRadioChange(e)}
                                    >
                                        {listConversations.map((item: any, index: number) => (
                                            <SelectItem key={index} value={item.sesion} textValue={item.sesion}>
                                                {item.nombre != "" ? item.nombre + " - " : ""} {item.sesion}
                                            </SelectItem>
                                        ))}
                                    </Select>
                                </div>
                                <div className="w-full p-2 flex flex-col justify-center items-center gap-2">
                                    <div className="w-full">
                                        <Input
                                            label="Comentario"
                                            name="text"
                                            type="textarea"
                                            value={commentary}
                                            onChange={(e) => setCommentary(e.target.value)}
                                        />
                                    </div>
                                    <div>
                                        <TypeMessageRe tipomensaje={message.tipomensaje} conversacion={message.conversacion} typeUser={message.quien_ejecuta_proceso} />
                                    </div>
                                </div>
                            </ModalBody>
                            <ModalFooter>
                                <Button type="button" color="danger" variant="solid" isDisabled={loading} onClick={() => hadleCloseModalReSend()}>
                                    Cancelar
                                </Button>
                                <Button type="button" color="primary" variant="solid" isLoading={loading} onClick={() => handleSubmit()}>
                                    {loading ? "Reenviando ..." : "Reenviar"}
                                </Button>
                            </ModalFooter>
                        </>
                    )}
                </ModalContent>
            </Modal>
        </>
    )
}

export default ReSendMessage